@@ -7,6 +7,7 @@ from .ObsFileCache import ObsFileCache
 from .OssFileCache import OssFileCache
 
 from .SynologyFileCache import SynologyFileCache
+from bbcloud_python_sdk.Api.Models.Artifacts import Artifacts
 
 
 def runtime_logging(func):
@@ -59,21 +60,81 @@ class FileCache():
         return self
 
     @runtime_logging
-    def set(self, key, file_path, del_local=True, set_all_area=False):
+    def set(self, key, file_path, del_local=True, set_all_area=False, artifacts_config=None):
         if set_all_area:
-            self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
-                                                                            del_local=False)
+            is_set = self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
+                                                                                     del_local=False)
+            if is_set and artifacts_config is not None:
+                self.create_artifacts(
+                    key=key,
+                    namespace=self.namespace,
+                    name=artifacts_config['name'],
+                    engine=self.default_engine.__class__.__name__,
+                    describe=artifacts_config['describe'],
+                    jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
+                    build_id=artifacts_config['build_id'],
+                    ttl=artifacts_config['ttl'],
+                    is_scan_code_download=artifacts_config['is_scan_code_download']
+                )
+
             for area in self.available_area:
                 if area is not self.using_area:
-                    self.getEngine(using_area=area).set_namespace(namespace=self.namespace).set(key=key,
-                                                                                                file_path=file_path,
-                                                                                                del_local=False)
-            if del_local:
-                if os.path.exists(file_path):
-                    os.remove(file_path)
+                    engine = self.getEngine(using_area=area)
+                    is_set = engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
+                                                                                del_local=False)
+                    if is_set and artifacts_config is not None:
+                        self.create_artifacts(
+                            key=key,
+                            namespace=self.namespace,
+                            name=artifacts_config['name'],
+                            engine=engine.__class__.__name__,
+                            describe=artifacts_config['describe'],
+                            jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
+                            build_id=artifacts_config['build_id'],
+                            ttl=artifacts_config['ttl'],
+                            is_scan_code_download=artifacts_config['is_scan_code_download']
+                        )
         else:
-            return self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
-                                                                                   del_local=del_local)
+            is_set = self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
+                                                                                     del_local=del_local)
+            if is_set and artifacts_config is not None:
+                self.create_artifacts(
+                    key=key,
+                    namespace=self.namespace,
+                    name=artifacts_config['name'],
+                    engine=self.default_engine.__class__.__name__,
+                    describe=artifacts_config['describe'],
+                    jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
+                    build_id=artifacts_config['build_id'],
+                    ttl=artifacts_config['ttl'],
+                    is_scan_code_download=artifacts_config['is_scan_code_download']
+                )
+
+        return is_set
+
+    def create_artifacts(self, key, namespace, engine, name=None, describe=None, jenkins_jobs_id=None, build_id=None,
+                         ttl=60 * 60 * 24 * 15,
+                         is_scan_code_download=False):
+        path = "%s/%s" % (namespace, key)
+        try:
+            Artifacts().updateOrCreate(
+                {
+                    'path': path,
+                    'engine': engine,
+                },
+                {
+                    'name': key if name is None else name,
+                    'describe': describe,
+                    'path': path,
+                    'engine': engine,
+                    'jenkins_jobs_id': jenkins_jobs_id,
+                    'build_id': build_id,
+                    'ttl': ttl,
+                    'is_scan_code_download': 1 if is_scan_code_download else 0,
+                }
+            )
+        except Exception as e:
+            logging.info('制品创建失败:%s' % e)
 
     @runtime_logging
     def get(self, key, local_file, default=None, auto_unzip=False, auto_delete_local_zip=True, auto_untar=False,
